@@ -101,8 +101,8 @@ class PMMArgs:
             self.choices[o["key"]] = parse_choice(o["env"], getattr(args_parsed, o["key"]), arg_int=o["type"] == "int", arg_bool=o["type"] == "bool")
 
     def __getitem__(self, key):
-        if key in self.options:
-            return self.options[key]
+        if key in self.choices:
+            return self.choices[key]
         raise KeyError(key)
 
     @property
